#include <iostream>
#include <algorithm>
#include <cstdio>
#include <iomanip>
#include <set>
#include <map>
#include <unordered_set>
#include <unordered_map>
#include <cassert>
#include <cmath>
#include <random>
#include <chrono>
#include <bitset>
#include <vector>
#include <immintrin.h>
#include <stack>
#include <deque>
#include <queue>

struct Edge {
    int32_t dst;
    int32_t x, y; // me to him
    int32_t modded_frac;

    Edge(int32_t dst_, int32_t x_, int32_t y_) {
        dst = dst_;
        x = x_;
        y = y_;
    }
};

#define MOD 998'244'353

int32_t bin_pow(int32_t base, int32_t power) {
    if(power == 0)
        return 1;
    if(power == 1)
        return base;
    int32_t prev = bin_pow(base, power / 2);
    prev = ((int64_t)prev * prev) % MOD;
    if(power % 2 == 1)
        prev = ((int64_t)prev * base) % MOD;
    return prev;
}

std::vector<int32_t>* primes;
void dfs(int32_t v, int32_t parent, std::vector<Edge>* tree, int32_t& sum, int32_t rel_cur, std::map<int32_t, int32_t>& freq_per_prime,
         std::map<int32_t, int32_t>& min_per_prime) {
    sum = (sum + rel_cur) % MOD;
    for(int32_t i = 0; i < tree[v].size(); i++)
        if(tree[v][i].dst != parent) {
            for(int32_t p : primes[tree[v][i].y])
                freq_per_prime[p]++;
            for(int32_t p : primes[tree[v][i].x]) {
                freq_per_prime[p]--;
                min_per_prime[p] = std::min(min_per_prime[p], freq_per_prime[p]);
            }

            dfs(tree[v][i].dst, v, tree, sum, ((int64_t)rel_cur * tree[v][i].modded_frac) % MOD, freq_per_prime, min_per_prime);

            for(int32_t p : primes[tree[v][i].y])
                freq_per_prime[p]--;
            for(int32_t p : primes[tree[v][i].x])
                freq_per_prime[p]++;
        }
}

int main() {
    primes = new std::vector<int32_t>[200'005];
    for(int32_t i = 1; i < 200'005; i++) {
        int32_t copy = i;
        for(int32_t j = 2; j * j <= copy; j++)
            while(copy % j == 0) {
                primes[i].push_back(j);
                copy /= j;
            }
        if(copy != 1)
            primes[i].push_back(copy);
    }

    std::ios::sync_with_stdio(false);
    std::cin.tie(0);

    int32_t num_tests;
    std::cin >> num_tests;

    for(int32_t t = 0 ;t < num_tests; t++) {
        int32_t n;
        std::cin >> n;

        std::vector<Edge>* tree = new std::vector<Edge>[n];
        for(int32_t i = 0; i < n - 1; i++) {
            int32_t src, dst, x, y;
            std::cin >> src >> dst >> x >> y;
            src--;
            dst--;

            tree[src].emplace_back(dst, x, y);
            tree[src].back().modded_frac = ((int64_t)y * bin_pow(x, MOD - 2)) % MOD;
            tree[dst].emplace_back(src, y, x);
            tree[dst].back().modded_frac = ((int64_t)x * bin_pow(y, MOD - 2)) % MOD;
        }

        int32_t rel_sum = 0;
        std::map<int32_t, int32_t> freq_per_prime, min_per_prime;
        dfs(0, -1, tree, rel_sum, 1, freq_per_prime, min_per_prime);

        int32_t ans = 1;
        for(auto it : min_per_prime) {
            ans = ((int64_t)ans * bin_pow(it.first, -it.second)) % MOD;
        }

        std::cout << ((int64_t)ans * rel_sum) % MOD << "\n";
    }
    return 0;
}




