#include <cmath>
#include <ctime>
#include <random>
#include <cassert>
#include <algorithm>
#include <iostream>
#include <vector>
#include <string>
#include <bitset>
#include <queue>
#include <set>
#include <unordered_set>
#include <map>
#include <unordered_map>

using namespace std;

#define all(a) (a).begin(), (a).end()
#define reverse_all(a) (a).rbegin(), (a).rend()

typedef long long ll;
typedef unsigned long long ull;
typedef long double ld;


const ll MD = 998244353, MAX_N = 2e5;
ll rev[MAX_N + 1];
vector < pair < int, int > > prec[MAX_N + 1];


ll bin_pow(ll base, int deg) {
	if (deg == 0)
		return 1;

	if (deg % 2 == 1)
		return (base * bin_pow(base, deg - 1)) % MD;

	ll tmp = bin_pow(base, deg / 2);
	return (tmp * tmp) % MD;
}


class FenwickTree {
	vector < int > sm;

public:
	FenwickTree(int sz) {
		sm.resize(sz + 1, 0);
	}

	void change(int x, int add) {
		for (int i = x + 1; i < sm.size(); i += i & -i)
			sm[i] += add;
	}

	int prefix_sum(int x) {
		int res = 0;
		for (int i = x + 1; i > 0; i -= i & -i)
			res += sm[i];
		return res;
	}

	int sum(int i, int j) {
		return prefix_sum(j) - prefix_sum(i - 1);
	}
};


struct Edge {
	int to, x, y;

	Edge(int to, int x, int y) {
		this->to = to;
		this->x = x;
		this->y = y;
	}
};


void get_result(int v, int p, vector < vector < Edge > >& g, unordered_map < int, int >& res, unordered_map < int, int >& cur, ll& sm, ll val) {
	sm = (sm + val) % MD;
	for (Edge ed : g[v]) {
		if (ed.to == p)
			continue;

		vector < pair < int, int > > delt;
		for (int i = 0, j = 0; i < prec[ed.x].size() || j < prec[ed.y].size(); ) {
			int vl, deg;
			if (j == prec[ed.y].size() || (i < prec[ed.x].size() && prec[ed.x][i].first < prec[ed.y][j].first)) {
				vl = prec[ed.x][i].first;
				deg = -prec[ed.x][i].second;
				i++;
			}
			else if (i == prec[ed.x].size() || (j < prec[ed.y].size() && prec[ed.x][i].first > prec[ed.y][j].first)) {
				vl = prec[ed.y][j].first;
				deg = prec[ed.y][j].second;
				j++;
			}
			else {
				vl = prec[ed.x][i].first;
				deg = prec[ed.y][j].second - prec[ed.x][i].second;
				i++;
				j++;
			}

			cur[vl] += deg;
			res[vl] = max(res[vl], cur[vl]);
			delt.push_back({ vl, deg });
		}

		get_result(ed.to, v, g, res, cur, sm, (((val * ed.x) % MD) * rev[ed.y]) % MD);

		for (pair < int, int > el : delt)
			cur[el.first] -= el.second;
	}
}


signed main() {
	ios_base::sync_with_stdio(0); cin.tie(0); cout.tie(0);

	for (int i = 1; i <= MAX_N; i++) {
		int cur = i;
		for (int d = 2; d * d <= cur; d++) {
			if (cur % d == 0)
				prec[i].push_back({ d, 0 });

			for (; cur % d == 0; prec[i].back().second++, cur /= d) {}
		}
		if (cur > 1)
			prec[i].push_back({ cur, 1 });

		rev[i] = bin_pow(i, MD - 2);
	}

	int t;
	cin >> t;

	for (; t; t--) {
		int n;
		cin >> n;

		vector < vector < Edge > > g(n);
		for (int v = 0; v < n - 1; v++) {
			int i, j, x, y;
			cin >> i >> j >> x >> y;

			g[--j].push_back(Edge(--i, x, y));
			g[i].push_back(Edge(j, y, x));
		}

		ll sm = 0;
		unordered_map < int, int > cur, res;
		get_result(0, 0, g, res, cur, sm, 1);

		ll x = 1;
		for (auto el : res)
			x = (x * bin_pow(el.first, el.second)) % MD;

		cout << (x * sm) % MD << "\n";
	}

	return 0;
}