#pragma GCC optimize("O3")
#pragma GCC target("sse,sse2,sse3,sse4,avx,avx2")

#include <bits/stdc++.h>
#include <ext/pb_ds/tree_policy.hpp>
#include <ext/pb_ds/assoc_container.hpp>

using namespace __gnu_pbds;

typedef long long ll;

int sum(int a, int b, int MOD) {
    int res = a + b;
    if (res >= MOD) res -= MOD;
    return res;
}

int sub(int a, int b, int MOD) {
    int res = a - b;
    if (res < 0) res += MOD;
    return res;
}

int mul(int a, int b, int MOD) {
    return (int)(1ll * a * b % MOD);
}

struct Hasher {
    int P, MOD;
    std::vector<int> powers, hash;

    Hasher(const std::string &s, int P, int MOD) : P(P), MOD(MOD) {
        int n = s.size();
        powers.resize(n + 1);
        powers[0] = 1;
        for (int i = 1; i <= n; i++) powers[i] = mul(powers[i - 1], P, MOD);
        hash.resize(n);
        hash[0] = s[0];
        for (int i = 1; i < n; i++) {
            hash[i] = sum(mul(hash[i - 1], P, MOD), s[i], MOD);
        }
    }

    int get(int l, int r) {
        int res = hash[r];
        if (l != 0) res = sub(res, mul(hash[l - 1], powers[r - l + 1], MOD), MOD);
        return res;
    }
};

int P, MOD;
std::string s;

std::pair<std::string, std::vector<int>> solveWPoss(int left, int right, int bit, std::vector<int> &poss) {
    if (left == right) {
        return std::make_pair(std::string(1, s[left]), poss);
    }
    int mid = (left + right) / 2;
    std::vector<int> possl, possr;
    for (const int & pos : poss) {
        if (pos & (1ll << bit)) {
            possr.push_back(pos);
        } else {
            possl.push_back(pos);
        }
    }
    std::string ans;
    std::vector<int> ansp;

    if (!possl.empty()) {
        auto ansl = solveWPoss(left, mid, bit - 1, possl);
        auto ansr = solveWPoss(mid + 1, right, bit - 1, ansl.second);
        ans = ansl.first + ansr.first;
        for (auto &val : ansr.second) {
            ansp.push_back(val);
        }
    }
    if (!possr.empty()) {
        auto ansr = solveWPoss(mid + 1, right, bit - 1, possr);
        auto ansl = solveWPoss(left, mid, bit - 1, ansr.second);
        if (ans.empty() || ansr.first + ansl.first < ans) {
            ans = ansr.first + ansl.first;
            ansp.clear();
            for (auto &val : ansl.second) {
                ansp.push_back(val | (1 << bit));
            }
        } else if (ansr.first + ansl.first == ans) {
            for (auto &val : ansl.second) {
                ansp.push_back(val | (1 << bit));
            }
        }
    }
    return std::make_pair(ans, ansp);
}

std::mt19937 rnd;

int getP(int l, int r) {
    return rnd() % (r - l + 1) + l;
}

bool isPrime(int n) {
    for (int i = 2; i * i <= n; i++) {
        if (n % i == 0) return false;
    }
    return true;
}

int getMod(int l, int r) {
    while (true) {
        int res = getP(l, r);
        if (isPrime(res)) return res;
    }
    assert(false);
}

void solve() {
    double START = clock();

    P = getP(200, 400) | 1;
    MOD = getMod(1e9 - 100, 1e9 + 100);
    int n;
    std::cin >> n >> s;
    std::string s1 = s;
    int ops = 0;
    while (true) {
        if (ops > 1e6 && (clock() - START) / CLOCKS_PER_SEC > 2.9) break;
        ops += n;
        int key = rnd() % (1 << n);
        std::string now(1 << n, '0');
        for (int i = 0; i < (1 << n); i++) {
            now[i ^ key] = s[i];
        }
        s1 = std::min(s1, now);
    }
    std::cout << s1 << '\n';
}

signed main() {
    int t = 1;
//    std::cin >> t;
    while (t--) {
        solve();
    }
}
