#include <iostream>
#include <algorithm>
#include <vector>
#include <cmath>
#include <climits>
#include <cstdio>
#include <array>
#include <string>
#include <set>
#include <map>
std::map<int,int> add(const std::map<int,int>& a, std::map<int,int> b)
{
	//copy b!
	for(auto[k, v] : a) b[k] += v;
	return b;
}
std::map<int,int> sub(std::map<int,int> a, const std::map<int,int>& b)
{
	//copy a!
	for(auto[k, v] : b) a[k] -= v;
	//for(auto it = a.begin(); it != a.end();)
	//{
	//	if(it->second == 0) a.erase(it);
	//	else ++it;
	//}
	return a;
}
const int64_t MOD = 998244353;
int64_t powmod(int64_t a, int64_t e, int64_t mod)
{
	int64_t r = 1;
	while(e)
	{
		if(e % 2) r = r * a % mod;
		a = a * a % mod;
		e >>= 1;
	}
	return r;
}
int64_t modinv(int64_t a)
{
	return powmod(a, MOD-2, MOD);
}
struct edge
{
	int to; int x; int y;
};
std::vector<std::vector<edge>> graph;
std::vector<std::map<int,int>> expvs;
std::vector<char> is_p;
std::vector<int> primes;
std::vector<int> sieve(int n)
{
	is_p.assign(n, true);
	is_p[0] = is_p[1] = false;
	for(int i = 2; i * i < n; i++)
	{
		for(int j = i*i; j < n; j += i)
			is_p[j] = false;
	}
	std::vector<int> ret;
	for(int i = 0; i < n; i++)
		if(is_p[i]) ret.push_back(i);
	return ret;
}
std::map<int,int> factor(int n)
{
	std::map<int,int> ret {};
	if(n == 1) return ret;
	if(is_p[n])
	{
		ret[n] = 1;
		return ret;
	}
	for(int p : primes)
	{
		while(n % p == 0) n /= p, ret[p]++;
		if(n == 1) break;
	}
	return ret;
}
std::vector<int> mins;
int64_t cost = 0;
void dfs(int at, int prev, std::map<int,int>& cur_expv, int64_t cc)
{
	cost += cc;
	cost %= MOD;
	//printf("at=%d cost=%lld prev=%d\n", at, cc, prev);
	//for(auto[k, v] : cur_expv) if(v != 0) printf("%d^%d ", k, v); printf("\n");
	for(auto[to,x,y] : graph[at])
	{
		if(to == prev) continue;
		auto dv = sub(factor(y), factor(x));
		for(auto[k, v] : dv)
		{
			cur_expv[k] += v;
			//printf("k=%d\n", k);
			mins[k] = std::min(mins[k], cur_expv[k]);
		}
		int64_t ncost = cc * y % MOD * modinv(x) % MOD;
		dfs(to, at, cur_expv, ncost);
		for(auto[k, v] : dv)
		{
			cur_expv[k] -= v;
			mins[k] = std::min(mins[k], cur_expv[k]);
		}
	}
}

int main()
{
	primes = sieve(2e5+10);
	int T; std::cin >> T;
	while(T --> 0)
	{
		int n; std::cin >> n;
		mins.assign(n+10, 0);
		// x,y can be factorized
		// use exponent vectors
		// min on each exponent vector must be zero
		// multiply to ensure that
		// 
		graph.assign(n, {});
		cost = 0;
		for(int i = 0; i < n-1; i++)
		{
			int u,v,x,y; scanf("%d%d%d%d", &u,&v,&x,&y);
			u--; v--;
			//printf("%d<->%d\n", u, v);
			graph[u].push_back({v, x, y});
			graph[v].push_back({u, y, x});
		}
		std::map<int,int> e0 {};
		//printf("calling dfs\n");
		dfs(0, -1, e0, 1);
		//printf("c0=%lld\n", cost);
		for(int i = 0; i < mins.size(); i++)
		{
			//if(mins[i] < 0) printf("%d: %d\n", i, mins[i]);
			cost *= powmod(i, -mins[i], MOD);
			cost %= MOD;
		}
		printf("%lld\n", cost);
	}
}
