#include <iostream>
#include <vector>
#include <string>
#include <set>
#include <map>
#include <unordered_map>
#include <unordered_set>
#include <algorithm>
#include <iomanip>
#include <assert.h>
#include <bitset>

using ll = long long;

using namespace std;

struct STree
{
    vector<int> t;
    vector<int> m;

    inline void push(int v, int tl, int tr)
    {
        int tm = (tl + tr) / 2;
        t[v * 2] += m[v] * (tm - tl + 1);
        m[v * 2] += m[v];

        t[v * 2 + 1] += m[v] * (tr - tm);
        m[v * 2 + 1] += m[v];

        m[v] = 0;
        t[v] = t[v * 2] + t[v * 2 + 1];
    }

    void build(int v, int tl, int tr, vector<int>& a)
    {
        if (tl == tr)
        {
            t[v] = a[tl];
        }
        else
        {
            int tm = (tl + tr) / 2;
            build(v * 2, tl, tm, a);
            build(v * 2 + 1, tm + 1, tr, a);
            t[v] = t[v * 2] + t[v * 2 + 1];
        }
    }

    void upd(int v, int tl, int tr, int ql, int qr, int x)
    {
        if (ql > qr) return;
        if (tl == ql && tr == qr)
        {
            t[v] += (tr - tl + 1) * x;
            m[v] += x;
        }
        else
        {
            push(v, tl, tr);
            int tm = (tl + tr) / 2;

            upd(v * 2, tl, tm, ql, min(qr, tm), x);
            upd(v * 2 + 1, tm + 1, tr, max(tm + 1, ql), qr, x);

            t[v] = t[v * 2] + t[v * 2 + 1];
        }
    }

    int get(int v, int tl, int tr, int ql, int qr)
    {
        if (ql > qr) return 0;
        if (tl == ql && tr == qr) return t[v];
        int tm = (tl + tr) / 2;
        int l = get(v * 2, tl, tm, ql, min(tm, qr));
        int r = get(v * 2 + 1, tm + 1, tr, max(tm + 1, ql), qr);
        return l + r;
    }

    STree() {};
    STree(vector<int>& a)
    {
        int n = a.size();
        int k = 1;
        while (k < n)
            k <<= 1;
        t.resize(k * 2);
        m.resize(k * 2);
        build(1, 0, n - 1, a);
    }

    STree(int n)
    {
        int k = 1;
        while (k < n)
            k <<= 1;
        t.resize(k * 2);
        m.resize(k * 2);
    }
};


const ll inf = 1e16;
const int mod = 998244353;
const int N = 2e5 + 10;

ll add(ll a, ll b)
{
    ll r = a + b;
    if (r >= mod) r -= mod;
    if (r < 0) r += mod;
    return r;
}

ll mul(ll a, ll b)
{
    return (a * b) % mod;
}

ll bp(ll a, ll n)
{
    ll r = 1;
    while (n)
    {
        if (n & 1)
            r = (r * a) % mod;
        a = (a * a) % mod;
        n >>= 1;
    }
    return r;
}

ll rev(ll a)
{
    return bp(a, mod - 2);
}

ll gcd(ll a, ll b)
{
    if (b == 0) return a;
    return gcd(b, a % b);
}

vector < pair<int, pair<ll, ll>>> g[N];
map<int, int> cnt;
ll lp[N];
char used[N];

void dfs(int v, map<int, int> &d)
{
    used[v] = 1;
    for (auto &[u, s] : g[v])
    {
        if (used[u]) continue;
        ll p = s.first;
        ll q = s.second;
        
        for (; p != 1;)
        {
            d[lp[p]]--;
            cnt[lp[p]] = max(cnt[lp[p]], d[lp[p]]);
            p /= lp[p];
        }

        for (; q != 1;)
        {
            d[lp[q]]++;
            cnt[lp[q]] = max(cnt[lp[q]], d[lp[q]]);
            q /= lp[q];
        }
    
        dfs(u, d);
    
        p = s.first;
        q = s.second;
    
        for (; p != 1;)
        {
            d[lp[p]]++;
            p /= lp[p];
        }

        for (; q != 1;)
        {
            d[lp[q]]--;
            q /= lp[q];
        }
    }
}

void dfs1(int v, ll cur, ll& ans)
{
    ans = add(ans, cur);
    used[v] = 1;
    for (auto& [u, s] : g[v])
    {
        if (used[u]) continue;
        ll p = s.first;
        ll q = s.second;
        dfs1(u, mul(mul(cur, p), rev(q)), ans);
    }
}

void solve()
{
    int n;
    cin >> n;

    cnt.clear();
    for (int i = 0; i < n; i++)
    {
        used[i] = 0;
        g[i].clear();
    }

    for (int p = 0; p < n - 1; p++)
    {
        int i, j, x, y;
        cin >> i >> j >> x >> y;
        i--, j--;
        g[i].push_back({ j, {y, x} });
        g[j].push_back({ i, {x, y} });
    }
    
    map<int, int> q;
    dfs(0, q);

    ll m = 1;

    for (auto& [a, b] : cnt)
    {
        m = mul(m, bp(a, b));
    }

    fill(used, used + n, 0);
    ll ans = 0;

    dfs1(0, m, ans);

    cout << ans << '\n';
}

signed main()
{
    ios_base::sync_with_stdio(0);
    cin.tie(0);

    int t = 1;
    cin >> t;

    for (int i = 0; i < N; i++)
    {
        lp[i] = i;
    }

    for (ll i = 2; i < N; i++)
    {
        if (lp[i] == i)
        {
            for (ll j = i * i; j < N; j += i)
            {
                lp[j] = min(lp[j], i);
            }
        }
    }


    while (t--)
    {
        solve();
    }

    return 0;
}
