#include <iostream>
#include <vector>
#include <set>
#include <tuple>
#include <algorithm>
#include <map>
#include <string>
#include <numeric>
#include <unordered_set>
#include <unordered_map>
#include <random>
#include <iomanip>
#include <queue>
#include <cassert>

using namespace std;

using ll = long long;
using ld = long double;
template <typename T>
using v = vector<T>;
template <typename A, typename B>
using pa = pair<A, B>;
template <typename... T>
using tup = tuple<T...>;

constexpr ll MOD = 998244353;

template <typename A, typename B>
inline istream& operator>> (istream& in, pa<A, B>& p);

template <typename T>
inline istream& operator>> (istream& in, v<T>& a) {
	for (T& t : a) {
		in >> t;
	}
	return in;
}

template <typename A, typename B>
inline istream& operator>> (istream& in, pa<A, B>& p) {
	return in >> p.first >> p.second;
}

v<v<tup<ll, ll, ll>>> graph;
v<ll> ratio_to_root;
ll resheto[(ll)2e5 + 1];

ll mulmod(ll a, ll b) {
	return (a * b) % MOD;
}

ll binpow(ll a, ll b) {
	if (b == 0) {
		return 1;
	}
	else if (b & 1) {
		return mulmod(binpow(a, b ^ 1), a);
	}
	else {
		ll p = binpow(a, b >> 1);
		return mulmod(p, p);
	}
}

struct denom_lcm {
	map<ll, ll> a;
	map<ll, ll> mia;
	denom_lcm() = default;
	void div(ll x) {
		--a[x];
		mia[x] = min(mia[x], a[x]);
	}
	void mul(ll x) {
		++a[x];
	}
	ll res() {
		ll cres = 1;
		for (pa<ll, ll> p : mia) {
			if (p.second < 0) {
				cres = mulmod(cres, binpow(p.first, -p.second));
			}
		}
		return cres;
	}
};

v<ll> factorize(ll a) {
	v<ll> res;
	while (a != 1) {
		res.push_back(resheto[a]);
		a /= resheto[a];
	}
	return res;
}

void dfs(ll vert, ll prt, ll ratio, denom_lcm& dl) {
	ratio_to_root[vert] = ratio;
	for (auto [overt, ox, oy] : graph[vert]) {
		if (overt != prt) {
			for (ll p : factorize(oy)) {
				dl.mul(p);
			}
			for (ll p : factorize(ox)) {
				dl.div(p);
			}
			dfs(overt, vert, mulmod(mulmod(ratio, binpow(ox, MOD - 2)), oy), dl);
			for (ll p : factorize(ox)) {
				dl.mul(p);
			}
			for (ll p : factorize(oy)) {
				dl.div(p);
			}
		}
	}
}

void build_resheto() {
	for (ll i = 2; i <= (ll)2e5; ++i) {
		if (resheto[i] == 0) {
			for (ll j = i; j <= (ll)2e5; j += i) {
				resheto[j] = i;
			}
		}
	}
}

inline void solve() {
	ll n;
	cin >> n;
	graph = v<v<tup<ll, ll, ll>>>(n);
	for (ll i = 0; i < n - 1; ++i) {
		ll a, b, x, y;
		cin >> a >> b >> x >> y;
		--a;
		--b;
		graph[a].push_back({ b, x, y });
		graph[b].push_back({ a, y, x });
	}
	ratio_to_root = v<ll>(n);
	denom_lcm dl;
	dfs(0, -1, 1, dl);
	ll l = dl.res();
	ll cres = 0;
	for (ll a : ratio_to_root) {
		cres += a;
		if (cres >= MOD) {
			cres -= MOD;
		}
	}
	cout << mulmod(l, cres) << '\n';
}

int main() {
	ios::sync_with_stdio(false);
	cin.tie(nullptr);
	cout.tie(nullptr);
	build_resheto();
	ll t = 1;
	cin >> t;
	for (ll i = 0; i < t; ++i) {
		solve();
	}
}