//#pragma GCC optimize("Ofast,unroll-loops")
//#pragma GCC target("avx,avx2,popcnt,lzcnt")

#include <iostream>
#include <vector>
#include <map>
#include <set>
#include <unordered_map>
#include <unordered_set>
#include <iomanip>
#include <algorithm>
#include <numeric>
#include <climits>
#include <random>
#include <cassert>

using namespace std;

typedef long long ll;
typedef long double ld;
typedef unsigned long long ull;

//#ifndef DESPAIR_101
//#define cerr if (false) cerr
//#endif

template<class A>
void print(A x) {
  cerr << x;
}
template<class A, class B>
void print(pair<A, B> x) {
  cerr << '(' << x.first << ' ' << x.second << ')';
}
template<class A>
void print(set<A> x) {
  for (A el : x) {
    print(el);
    cerr << ' ';
  }
  cerr << '\n';
}
template<class A>
void print(multiset<A> x) {
  for (A el : x) {
    print(el);
    cerr << ' ';
  }
  cerr << '\n';
}
template<class A>
void print(unordered_set<A> x) {
  for (A el : x) {
    print(el);
    cerr << ' ';
  }
  cerr << '\n';
}
template<class A>
void print(vector<A> x) {
  for (A el : x) {
    print(el);
    cerr << ' ';
  }
  cerr << '\n';
}
template<class A, class B>
void print(map<A, B> x) {
  for (pair<A, B> el : x) {
    print(el);
    cerr << ' ';
  }
  cerr << '\n';
}

//#define int ll
#define sz(x) int(x.size())
#define dbg(x) cerr << #x << ":\n "; print(x); cerr << "\n";

mt19937 rnd(time(0));
const int INF = int(1e9) + 7;

#ifdef DESPAIR_101
int __lg(ll x) {
  int i = 0;
  while (i <= 62 && (1ll << i) <= x) ++i;
  return i - 1;
}
#endif

ll binPow(ll a, ll n, ll m) {
  if (n == 0) return 1;
  if (n & 1) return a * binPow(a, n - 1, m) % m;
  return binPow(a * a % m, n / 2, m) % m;
}

struct edge {
  int to;
  int ch;
  int zn;
};

const int N = int(2e5) + 1;
int d[N], cur[N], fac[N];
const int MOD = 998244353;
ll ans = 0;

vector<pair<int, int>> factorize(int x) {
  vector<pair<int, int>> f;
  while (x != 1) {
    int div = d[x];
    f.emplace_back(div, 0);
    while (x % div == 0) {
      ++f.back().second;
      x /= div;
    }
  }
  return f;
}

void dfs(int u, int p, vector<vector<edge>>& g) {
  for (auto [to, ch, zn] : g[u]) {
    if (to == p) continue;
    vector<pair<int, int>> v1 = factorize(ch);
    for (auto [nmb, cnt] : v1) cur[nmb] += cnt;
    vector<pair<int, int>> v2 = factorize(zn);
    vector<pair<int, int>> o;
    for (auto [nmb, cnt] : v2) {
      o.emplace_back(nmb, cur[nmb]);
      if (cur[nmb] + fac[nmb] < cnt) {
        fac[nmb] += cnt - cur[nmb] - fac[nmb];
        cur[nmb] -= cnt;
      } else {
        cur[nmb] -= cnt;
      }
    }
    dfs(to, u, g);
    for (auto [nmb, cnt] : o) cur[nmb] = cnt;
    for (auto [nmb, cnt] : v1) cur[nmb] -= cnt;
  }
}

void getAns(int u, int p, ll nmb, vector<vector<edge>>& g) {
  ans += nmb;
  ans %= MOD;
  for (auto [to, ch, zn] : g[u]) {
    if (to == p) continue;
    getAns(to, u, nmb * ch % MOD * binPow(zn, MOD - 2, MOD) % MOD, g);
  }
}

void solve() {
  int n;
  cin >> n;

  ans = 0;
  vector<vector<edge>> g(n);

  for (int i = 0; i < n - 1; ++i) {
    int a, b, x, y;
    cin >> a >> b >> x >> y;
    int gc = gcd(x, y);
    x /= gc, y /= gc;
    --a, --b;
    g[a].push_back({ b, y, x });
    g[b].push_back({ a, x, y });
  }

  dfs(0, -1, g);
  ll c = 1;

  for (int i = 2; i <= n; ++i) {
    while (fac[i]) {
      --fac[i];
      c *= i;
      c %= MOD;
    }
  }

  getAns(0, -1, c, g);
  cout << ans << '\n';
}

signed main() {
  iota(d, d + N, 0);
  for (int i = 2; i < N; ++i) {
    if (d[i] == i && ll(i) * i < N) {
      for (int j = i * i; j < N; j += i) {
        d[j] = min(d[j], i);
      }
    }
  }

  cin.tie(nullptr)->ios::sync_with_stdio(false);
  cout << fixed << setprecision(20);

  int te = 1;
  cin >> te;
  for (int t = 1; t <= te; ++t) {
    cerr << "_____ TEST #" << t << " _____\n";
    solve();
  }
}