#include <bits/stdc++.h>

using namespace std;

struct Edge {
  int v, u;
  long long num;
  long long denom;

  Edge() = default;
  Edge(int _v, int _u, long long _num, long long _denom) : v(_v), u(_u), num(_num), denom(_denom) {};
};

const int MAXN = 2e5;
const int MOD = 998244353;

vector<Edge> graph[MAXN];
long long ans[MAXN];
long long modrev[MAXN + 1];
map<int, int> lcm_divs;
map<int, int> cur_divs;
map<int, int> num_divs;

long long bin_pow(long long base, long long p) {
  if (p == 0) {
    return 1;
  }
  if (p % 2 == 1) {
    return (bin_pow(base, p - 1) * base) % MOD;
  }
  auto res = bin_pow(base, p / 2);
  return (res * res) % MOD;
}

void dfs(int v, int p) {
  for (auto &[_v, u, num, denom]: graph[v]) {
    if (u == p)
      continue;

    long long cd = denom;
    map<int, int> cur_div;
    for (int i = 2; i * i <= denom; i++) {
      while (cd % i == 0) {
        cd /= i;
        cur_div[i]++;
      }
    }
    if (cd > 1) {
      cur_div[cd]++;
    }

    map<int, int> num_div;
    long long cn = num;
    for (int i = 2; i * i <= num; i++) {
      while (cn % i == 0) {
        cn /= i;
        num_div[i]++;
      }
    }
    if (cn > 1) {
      num_div[cn]++;
    }

    for (auto[div, cnt]: num_div) {
      num_divs[div] += cnt;
    }
    for (auto[div, cnt]: cur_div) {
      cur_divs[div] += cnt;
    }

    for (auto[div, cnt]: cur_div) {
      lcm_divs[div] = max(lcm_divs[div], max(0, cur_divs[div] - num_divs[div]));
    }
    dfs(u, v);

    for (auto[div, cnt]: cur_div) {
      cur_divs[div] -= cnt;
    }
    for (auto[div, cnt]: num_div) {
      num_divs[div] -= cnt;
    }
  }
}

void dfs2(int v, int p, long long cur_mul) {
  ans[v] = cur_mul;
  for (auto &[_v, u, num, denom]: graph[v]) {
    if (u == p)
      continue;
    long long next_mul = (cur_mul * num) % MOD;
    next_mul = (next_mul * modrev[denom]) % MOD;
    dfs2(u, v, next_mul);
  }
}

void solve() {
  int n;
  cin >> n;
  for (int i = 0; i < n; i++)
    graph[i].clear();
  lcm_divs.clear();
  cur_divs.clear();
  for (int i = 0; i < n - 1; i++) {
    int v, u, num, denom;
    cin >> v >> u >> num >> denom;
    v--;
    u--;
    graph[v].emplace_back(v, u, denom, num);
    graph[u].emplace_back(u, v, num, denom);
  }
  dfs(0, 0);
  long long cur_lcm = 1;
  for (auto[div, cnt]: lcm_divs) {
    long long M = bin_pow(div, cnt);
    cur_lcm = (cur_lcm * M) % MOD;
  }
  dfs2(0, 0, cur_lcm);
  long long ans_sum = 0;
  for (int i = 0; i < n; i++) {
    ans_sum = (ans_sum + ans[i]) % MOD;
  }
  cout << ans_sum << '\n';
}

signed main() {
  ios_base::sync_with_stdio(false);
  cin.tie(nullptr);
  for (int i = 1; i <= MAXN; i++) {
    modrev[i] = bin_pow(i, MOD - 2);
  }
  int t;
  cin >> t;
  while (t--) {
    solve();
  }
  return 0;
}