#define _CRT_SECURE_NO_WARNINGS
#include <iostream>
#include <vector>
#include <algorithm>
#include <map>
#include <set>
#include <cmath>

using namespace std;
using ll = long long;
using ld = long double;

const int MOD = 998244353;
const int N = 2e5 + 5;

vector<int> p(N);

void sieve()
{
	for (int i = 2; i < N; i++) {
		if (p[i]) {
			continue;
		}
		for (ll j = (ll)i * i; j < N; j += i) {
			if (!p[j]) {
				p[j] = i;
			}
		}
	}
}

ll binpow(ll val, ll q) {
	if (!q) {
		return 1;
	}
	if (q % 2) {
		return (val * binpow(val, q - 1)) % MOD;
	}
	return binpow((val * val) % MOD, q / 2);
}

struct Edge {
	int u, x, y;
	Edge(int a = 0, int b = 0, int c = 0) {
		u = a;
		x = b;
		y = c;
	}
};

void dfs(int v, int par, vector<vector<Edge>>& gr, vector<int>& done, vector<int>& need) {
	for (auto& to : gr[v]) {
		if (to.u == par) {
			continue;
		}
		vector<int> factx;
		int tmp = to.x;
		while (p[tmp] > 0) {
			factx.push_back(p[tmp]);
			tmp /= p[tmp];
		}
		factx.push_back(tmp);
		vector<int> facty;
		tmp = to.y;
		while (p[tmp] > 0) {
			facty.push_back(p[tmp]);
			tmp /= p[tmp];
		}
		facty.push_back(tmp);
		for (auto& elem : factx) {
			need[elem]++;
		}
		for (auto& elem : facty) {
			need[elem]--;
		}
		for (auto& elem : factx) {
			if (need[elem] > done[elem]) {
				done[elem] = need[elem];
			}
		}
		dfs(to.u, v, gr, done, need);
		for (auto& elem : factx) {
			need[elem]--;
		}
		for (auto& elem : facty) {
			need[elem]++;
		}
	}
}

int gcd(int a, int b) {
	if (!b) {
		return a;
	}
	return gcd(b, a % b);
}

void generate(int v, int p, ll curr, ll& ans, vector<vector<Edge>>& gr) {
	for (auto& to : gr[v]) {
		if (to.u == p) {
			continue;
		}
		ll tmp = (((curr * to.y) % MOD) * binpow(to.x, MOD - 2)) % MOD;
		ans = (ans + tmp) % MOD;
		generate(to.u, v, tmp, ans, gr);
	}
}

void solve()
{
	int n;
	cin >> n;
	vector<vector<Edge>> gr(n + 1);
	for (int i = 1; i < n; i++) {
		int tmpv, tmpu, tmpx, tmpy;
		cin >> tmpv >> tmpu >> tmpx >> tmpy;
		int tmp = gcd(tmpx, tmpy);
		tmpx /= tmp;
		tmpy /= tmp;
		gr[tmpv].push_back(Edge({ tmpu, tmpx, tmpy }));
		gr[tmpu].push_back(Edge({tmpv, tmpy, tmpx}));
	}
	vector<int> done(n + 1), need(n + 1);
	dfs(1, 1, gr, done, need);
	ll curr = 1;
	for (int i = 1; i < n + 1; i++) {
		curr = (curr * binpow(i, done[i])) % MOD;
	}
	ll ans = curr;
	generate(1, 1, curr, ans, gr);
	cout << ans << '\n';
}

int main()
{
#ifdef _DEBUG
	freopen("in.txt", "r", stdin);
	freopen("out.txt", "w", stdout);
#else
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);
#endif
	int t;
	sieve();
	for (cin >> t; t > 0; t--) {
		solve();
	}
}