#include <iostream>
#include <vector>
#include <array>

using namespace std;

const int MAX_N = int(2e5) + 7;
const int P_SIZE = 17985;
const int MOD = 998244353;

bool is_p[MAX_N];
int p[P_SIZE];

void build_p() {
    for (int i = 2; i < MAX_N; i++) {
        is_p[i] = true;
    }
    for (int i = 2; i * i < MAX_N; i++) {
        if (is_p[i]) {
            for (int j = i * i; j < MAX_N; j += i) {
                is_p[j] = false;
            }
        }
    }
    int sz = 0;
    for (int i = 0; i < MAX_N; i++) {
        if (is_p[i]) {
            p[sz++] = i;
        }
    }
}

int q_pow(int a, int n) {
    if (n == 0) {
        return 1;
    }
    int p = q_pow(a, n / 2);
    p = (p * 1ll * p) % MOD;
    if (n % 2) {
        p = (p * 1ll * a) % MOD;
    }
    return p;
}

struct number {
    int cnt[P_SIZE];

    number(int a = 1) {
        for (int i = 0; i < P_SIZE; i++) {
            cnt[i] = 0;
            while (a % p[i] == 0) {
                cnt[i]++;
                a /= p[i];
            }
        }
    }

    int get_int() const {
        int res = 1;
        for (int i = 0; i < P_SIZE; i++) {
            res = (res * 1ll * q_pow(p[i], cnt[i])) % MOD;
//            if (cnt[i]) {
//                cout << "p = " << p[i] << ", cnt = " << cnt[i] << "\n";
//            }
        }
        return res;
    }

    friend number operator*(const number& a, const number& b) {
        number c(1);
        for (int i = 0; i < P_SIZE; i++) {
            c.cnt[i] = a.cnt[i] + b.cnt[i];
        }
        return c;
    }

    friend number operator/(const number& a, const number& b) {
        number c(1);
        for (int i = 0; i < P_SIZE; i++) {
            c.cnt[i] = a.cnt[i] - b.cnt[i];
        }
        return c;
    }
};

int get_gcd(int a, int b) {
    if (a == 0) {
        return b;
    }
    return get_gcd(b % a, a);
}

number get_gcd_number(const number& a, const number& b) {
    number c(1);
    for (int i = 0; i < P_SIZE; i++) {
        c.cnt[i] = min(a.cnt[i], b.cnt[i]);
    }
    return c;
}

vector<vector<array<int, 3>>> gr;
vector<number> ans;

number dfs(int v, int p) {
    number res(1);
    for (const auto& el : gr[v]) {
        int u = el[0], x = el[1], y = el[2];
        if (u == p) {
            continue;
        }
        number u_res = dfs(u, v);
        u_res = u_res / get_gcd_number(u_res, number(y)) * number(x);
        res = res * u_res / get_gcd_number(res, u_res);
    }
    return res;
}

void dfs_ans(int v, int p, number res) {
    ans[v] = res;
    for (const auto& el : gr[v]) {
        int u = el[0], x = el[1], y = el[2];
        if (u == p) {
            continue;
        }
        dfs_ans(u, v, res / number(x) * number(y));
    }
}

void solve() {
    int n;
    cin >> n;
    gr.assign(n, vector<array<int,3>>());
    for (int i = 1; i < n; i++) {
        int u, v, x, y;
        cin >> v >> u >> x >> y;
        u--, v--;
        int d = get_gcd(x, y);
        x /= d;
        y /= d;
        gr[u].push_back({ v, y, x });
        gr[v].push_back({ u, x, y });
    }
    auto res = dfs(0, 0);
    ans.resize(n);
    dfs_ans(0, 0, res);
    int answer = 0;
    for (int i = 0; i < n; i++) {
        answer += ans[i].get_int();
//        cout << i << " -> " << ans[i].get_int() << "\n";
        answer %= MOD;
    }
    cout << answer << "\n";
}

int main() {
    ios_base::sync_with_stdio(0), cin.tie(0), cout.tie(0);
    build_p();
    int t;
    cin >> t;
    for (int i = 0; i < t; i++) {
        solve();
    }
}
