#include <iostream>
#include <iomanip>
#include <cstdio>
#include <vector>
#include <string>
#include <set>
#include <map>
#include <unordered_set>
#include <unordered_map>
#include <deque>
#include <queue>
#include <numeric>
#include <algorithm>

#define all(a) (a).begin(), (a).end()
#define ssize(a) (int)(a).size()

using namespace std;

using ll = long long;


const int mod = 998244353;

int prod(int a, int b) {
	return (ll)a * b % mod;
}

int sum(int a, int b) {
	if (a + b >= mod) {
		return a + b - mod;
	}
	return a + b;
}

int binpow(int a, int p) {
	if (p == 0) {
		return 1;
	}
	if (p % 2 == 0) {
		return binpow(prod(a, a), p / 2);
	}
	return prod(a, binpow(a, p - 1));
}


int inv(int a) {
	return binpow(a, mod - 2);
}

const int maxn = 2e5 + 10;

vector<int> primes;
vector<pair<int, int>> num_primes[maxn];

void precalc() {
	vector<char> sieved(maxn, false);
	for (int i = 2; i < maxn; ++i) {
		if (!sieved[i]) {
			primes.push_back(i);
			for (int j = i; j < maxn; j += i) {
				sieved[j] = true;
				num_primes[j].push_back({ ssize(primes) - 1, 0 });
			}
		}
	}
	for (int i = 1; i < maxn; ++i) {
		for (auto&[p, a] : num_primes[i]) {
			int j = i;
			while (j % primes[p] == 0) {
				++a;
				j /= primes[p];
			}
		}
	}
}

vector<vector<tuple<int, int, int>>> g;
vector<int> min_pwr;
vector<int> cur_pwr;
int ans;

void dfs1(int v, int p) {
	for (auto[u, x, y] : g[v]) {
		if (u == p)
			continue;

		for (auto&[p, a] : num_primes[x]) {
			cur_pwr[p] += a;
		}
		for (auto&[p, a] : num_primes[y]) {
			cur_pwr[p] -= a;
			min_pwr[p] = min(min_pwr[p], cur_pwr[p]);
		}

		dfs1(u, v);

		for (auto&[p, a] : num_primes[y]) {
			cur_pwr[p] += a;
		}
		for (auto&[p, a] : num_primes[x]) {
			cur_pwr[p] -= a;
		}
	}
}



void dfs2(int v, int p, int vol) {
	ans = sum(ans, vol);

	for (auto[u, x, y] : g[v]) {
		if (u == p)
			continue;

		int u_vol = prod(vol, x);
		u_vol = prod(u_vol, inv(y));

		dfs2(u, v, u_vol);
	}
}


void solve() {
	int n;
	cin >> n;

	g.assign(n, vector<tuple<int, int, int>>());

	for (int e = 0; e < n - 1; ++e) {
		int i, j, x, y;
		cin >> i >> j >> x >> y;
		--i, --j;
		g[i].push_back({ j, y, x });
		g[j].push_back({ i, x, y });
	}


	int primes_cnt = upper_bound(all(primes), n) - primes.begin();
	ans = 0;
	min_pwr.assign(primes_cnt, 0);
	cur_pwr.assign(primes_cnt, 0);

	dfs1(0, -1);

	int s_vol = 1;
	
	for (int p = 0; p < primes_cnt; ++p) {
		if (min_pwr[p] < 0) {
			s_vol = prod(s_vol, binpow(primes[p], -min_pwr[p]));
		}
	}


	dfs2(0, -1, s_vol);

	cout << ans << "\n";
}

int main() {
#ifdef LOCAL
	freopen("input.txt", "r", stdin);
#endif
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);

	precalc();

	int t = 1;
	cin >> t;
	while (t--) {
		solve();
	}

	return 0;
}