#include <iostream>
#include <vector>
#include <algorithm>
#include <set>
#include <map>
#include <unordered_set>
#include <unordered_map>
#include <cassert>
#include <queue>
#include <deque>
#include <numeric>
#include <bitset>
#include <random>

using namespace std;

#define int long long
#define all(x) x.begin(), x.end()

const int maxn = 3e5; //  don't forget to change this if needed
const int mod = 998'244'353;
const int inf = 1e18;
mt19937_64 rnd;

struct dsu {
    int p[maxn];
    int sz[maxn];
    
    void init(int n) {
        fill(sz, sz + n, 1);
        iota(p, p + n, 0);
    }
    
    int color(int v) {
        return (v == p[v] ? v : p[v] = color(p[v]));
    }
    
    void unite(int u, int v) {
        u = color(u);
        v = color(v);
        if (u == v) return;
        if (sz[u] < sz[v]) swap(u, v);
        sz[u] += sz[v];
        p[v] = u;
    }
};

int gcd(int a, int b) {
    if (!b) return a;
    return gcd(b, a % b);
}

pair<int, int> ext_gcd(int a, int b) {
    if (!b) return { 1, 0 };
    auto [xp, yp] = ext_gcd(b, a % b);
    int x = yp;
    int y = xp - yp * (a / b);
    return { x, y };
}

int bp(int x, int n = mod - 2) {
    int res = 1;
    while (n) {
        if (n & 1) {
            res *= x;
            res %= mod;
        }
        x *= x;
        x %= mod;
        n >>= 1;
    }
    return res;
}

const int k = 475;

map<int, int> divs[maxn];
map<int, int> edge[maxn];
int minDiv[maxn];
int h[maxn];
int res[maxn];

void dfs(int v, vector<vector<int>> &g, int p) {
    for (int u : g[v]) {
        if (u != p) {
            h[u] = h[v] + 1;
            dfs(u, g, v);
        }
    }
}

void dfs1(int v, vector<vector<int>> &g, int p) {
    for (int u : g[v]) {
        if (u != p) {
            dfs1(u, g, v);
            if (divs[v].size() < divs[u].size()) divs[v].swap(divs[u]);
        }
    }
    for (int u : g[v]) {
        if (u != p) {
            for (auto [a, b] : divs[u]) {
                divs[v][a] = max(0ll, max(divs[v][a], b));
            }
            divs[u].clear();
        }
    }
    for (auto [x, y] : edge[v]) {
        divs[v][x] = max(0ll, divs[v][x] + y);
    }
}

void dfs2(int v, vector<vector<pair<int, int>>> &g) {
    for (auto [u, w] : g[v]) {
        res[u] = (res[v] * w) % mod;
        dfs2(u, g);
    }
}

void solve() { //  suffix array has already been written
    int n;
    cin >> n;
    fill(h, h + n, 0);
    for (int i = 0; i < n; ++i) {
        divs[i].clear();
        edge[i].clear();
    }
    vector<vector<int>> g(n);
    vector<pair<pair<int, int>, pair<int, int>>> q;
    for (int i = 0; i + 1 < n; ++i) {
        int u, v, x, y;
        cin >> u >> v >> x >> y;
        --u; --v;
        g[u].push_back(v);
        g[v].push_back(u);
        q.push_back({ { u, v }, { x, y } });
    }
    vector<vector<pair<int, int>>> gp(n);
    dfs(0, g, -1);
    for (auto [q1, q2] : q) {
        auto [u, v] = q1;
        auto [x, y] = q2;
        int d = gcd(x, y);
        x /= d;
        y /= d;
        map<int, int> dx, dy;
        vector<int> c;
        while (x > 1) {
            ++dy[minDiv[x]];
            c.push_back(minDiv[x]);
            x /= minDiv[x];
        }
        while (y > 1) {
            ++dx[minDiv[y]];
            c.push_back(minDiv[y]);
            y /= minDiv[y];
        }
        x = q2.first;
        y = q2.second;
        swap(x, y);
        if (h[u] > h[v]) {
            swap(u, v);
            dx.swap(dy);
            swap(x, y);
        }
        gp[u].push_back({ v, (x * bp(y)) % mod });
        for (int i : c) {
            int b = dy[i] - dx[i];
            edge[v][i] = b;
        }
    }
    dfs1(0, g, -1);
    int ans = 0;
    int val0 = 1;
    for (auto [p, q] : divs[0]) {
        val0 *= bp(p, q);
        val0 %= mod;
    }
    res[0] = val0;
    dfs2(0, gp);
    for (int i = 0; i < n; ++i) {
        ans += res[i];
        ans %= mod;
    }
    cout << ans << '\n';
}

int32_t main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);
    for (int i = 1; i < maxn; ++i) {
        int j = 2;
        while (j * j <= i) {
            if (i % j == 0) {
                minDiv[i] = j;
                break;
            }
            ++j;
        }
        if (minDiv[i] == 0) {
            minDiv[i] = i;
        }
    }
    int t;
    cin >> t;
    while (t--) {
        solve();
    }
}
/*
 
 */
