#ifdef LOCAL
#pragma GCC optimize("Ofast")
#pragma GCC optimize("O3")
#endif

#include <iostream>
#include <vector>
#include <set>
#include <map>
#include <unordered_map>
#include <unordered_set>
#include <queue>
#include <deque>
#include <stack>
#include <string>
#include <algorithm>
#include <cmath>
#include <numeric>
#include <tuple>
#include <iomanip>
#include <random>
#include <cstdlib>

#define len(a) (int)a.size()
#define accuracy(a) fixed << setprecision(a)

typedef long long ll;
typedef long double ld;

const int INF = (int)1e9;
const int MINF = (int)2e9;
const ll LINF = (ll)1e18;
const ld EPS = 1e-9;
const int MOD = 998244353;

using namespace std;

void fast_io()
{
    ios_base::sync_with_stdio(0);
    cin.tie(0), cout.tie(0);
}

void file_in(const string& filename)
{
    freopen(filename.c_str(), "r", stdin);
}

void file_out(const string& filename)
{
    freopen(filename.c_str(), "w", stdout);
}

int randint(int a, int b)
{
    static random_device rd;
    static mt19937 rnd(rd());
    return (int)(rnd() % (b - a + 1)) + a;
}

double diff_clock(clock_t start, clock_t end)
{
    return (double)(end - start) * 1000 / CLOCKS_PER_SEC;
}

void sleep(int milliseconds)
{
    for (clock_t start = clock(); diff_clock(start, clock()) < milliseconds; ) {}
}

void run();
void gen();
void stupid();

signed main()
{
#ifdef LOCAL
    file_in("input.txt");
    file_out("output.txt");
    clock_t start = clock();
#else
    fast_io();
#endif

    run();
//    gen();
//    stupid();

#ifdef LOCAL
    cerr << "TIME = " << accuracy(3) << diff_clock(start, clock()) << '\n';
#endif
}

void gen()
{

}

void stupid()
{

}

/*void run()
{

}*/

int bin_pow(int a, int n)
{
    if (n == 0)
    {
        return 1;
    }
    int temp = bin_pow(a, n / 2);
    temp = (int)((ll)temp * temp % MOD);
    if (n % 2)
    {
        temp = (int)((ll)temp * a % MOD);
    }
    return temp;
}

vector<int> primes;

void sieve(int n)
{
    vector<char> line(n + 1);
    for (int i = 2; i <= n; ++i)
    {
        if (!line[i])
        {
            primes.push_back(i);
            for (ll j = (ll)i * i; j <= n; j += i)
            {
                line[j] = 1;
            }
        }
    }
}

struct Edge
{
    int to;
    int x;
    int y;

    Edge() : Edge(-1, 0, 0) {}
    Edge(int to, int x, int y) : to(to), x(x), y(y) {}
};

struct Nok
{
    vector<int> primes_count;
    vector<int> history;
    vector<char> used;

    void init()
    {
        primes_count.resize(len(primes));
        used.resize(len(primes));
    }

    void update(int prime_id, int prime_value)
    {
        if (prime_value > primes_count[prime_id])
        {
            primes_count[prime_id] = prime_value;
            history.emplace_back(prime_id);
        }
    }
    int get_nok()
    {
        int ans = 1;
        for (int i : history)
        {
            if (!used[i])
            {
                ans = (int)((ll)ans * bin_pow(primes[i], primes_count[i]) % MOD);
                used[i] = 1;
            }
        }
        return ans;
    }

    void clear()
    {
        for (int i : history)
        {
            primes_count[i] = 0;
            used[i] = 0;
        }
        history.clear();
    }
};

Nok nok;

struct CurNumber
{
    vector<int> primes_count;
    vector< pair<int, int> > history;

    void init()
    {
        primes_count.resize(len(primes));
    }

    void mult(int prime_ind)
    {
        --primes_count[prime_ind];
        history.emplace_back(prime_ind, -1);
    }

    void div(int prime_ind)
    {
        nok.update(prime_ind, ++primes_count[prime_ind]);
        history.emplace_back(prime_ind, 1);
    }

    void reverse()
    {
        auto [prime_ind, value] = history.back();
        history.pop_back();
        primes_count[prime_ind] -= value;
    }

    void reverse(int count)
    {
        for (int i = 0; i < count; ++i)
        {
            reverse();
        }
    }
};

CurNumber cur_number;

vector< vector<Edge> > graph;

vector<int> buffer;

void factorize(int n, vector<int>& primes_ind)
{
    for (int i = 0; primes[i] * primes[i] <= n; ++i)
    {
        while (n % primes[i] == 0)
        {
            primes_ind.push_back(i);
            n /= primes[i];
        }
    }
    if (n > 1)
    {
        primes_ind.push_back((int)distance(primes.begin(), lower_bound(primes.begin(), primes.end(), n)));
    }
}

void dfs(int v, int p = -1)
{
    for (Edge& edge : graph[v])
    {
        if (edge.to == p)
        {
            continue;
        }
        int reverse_count = 0;
        factorize(edge.x, buffer);
        reverse_count += len(buffer);
        while (!buffer.empty())
        {
            cur_number.mult(buffer.back());
            buffer.pop_back();
        }
        factorize(edge.y, buffer);
        reverse_count += len(buffer);
        while (!buffer.empty())
        {
            cur_number.div(buffer.back());
            buffer.pop_back();
        }
        dfs(edge.to, v);
        cur_number.reverse(reverse_count);
    }
}

int inv(int n)
{
    return bin_pow(n, MOD - 2);
}

int nok_;
int ans;

void dfs_ans(int v, int cur_numerator, int cur_denominator, int p = -1)
{
    ans += (int)((ll)cur_numerator * inv(cur_denominator) % MOD);
    if (ans >= MOD)
    {
        ans -= MOD;
    }
    for (Edge& edge : graph[v])
    {
        if (edge.to == p)
        {
            continue;
        }
        dfs_ans(edge.to, (int)((ll)cur_numerator * edge.x % MOD), (int)((ll)cur_denominator * edge.y % MOD), v);
    }
}

void solve_test()
{
    int n;
    cin >> n;
    graph.assign(n, vector<Edge>());
    nok.clear();
    for (int i = 0; i < n - 1; ++i)
    {
        int u, v, x, y;
        cin >> u >> v >> x >> y;
        --u, --v;
        graph[u].emplace_back(v, y, x);
        graph[v].emplace_back(u, x, y);
    }

    dfs(0);

    nok_ = nok.get_nok();
    ans = 0;

    dfs_ans(0, nok_, 1);

    cout << ans << '\n';
}

void run()
{
    sieve((int)2e5);
    nok.init();
    cur_number.init();

    int t;
    cin >> t;
    for (; t > 0; --t)
    {
        solve_test();
    }
}
